@@ -1,20 +1,5 @@
 #
 # otopi -- plugable installer
-# Copyright (C) 2012-2015 Red Hat, Inc.
-#
-# This library is free software; you can redistribute it and/or
-# modify it under the terms of the GNU Lesser General Public
-# License as published by the Free Software Foundation; either
-# version 2.1 of the License, or (at your option) any later version.
-#
-# This library is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-# Lesser General Public License for more details.
-#
-# You should have received a copy of the GNU Lesser General Public
-# License along with this library; if not, write to the Free Software
-# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 #
 
 
@@ -163,10 +148,10 @@ class MiniDNF():
                 _('Downloaded {payload}{status}{message}').format(
                     payload=payload,
                     status=(
-                        (_(' ') + self._STATUS_2_STR.get(status, _('Unknown')))
+                        (' ' + self._STATUS_2_STR.get(status, _('Unknown')))
                         if status else ''
                     ),
-                    message=(_(' ') + msg) if msg else '',
+                    message=(' ' + msg) if msg else '',
                 )
             )
 
@@ -260,7 +245,7 @@ class MiniDNF():
             if msgs:
                 self._sink.verbose(
                     _('Script out: {messages}').format(
-                        massages=msgs,
+                        messages=msgs,
                     )
                 )
 
